Learn R Programming

WAnova (version 0.4.0)

print.wsize: Print Method for `wsize` Objects

Description

Custom print method for objects of class `wsize`. Displays the results of the sample size determination in a user-friendly format.

Usage

# S3 method for wsize
print(x, ...)

Value

Prints the sample size determination results to the console.

Arguments

x

An object of class wsize.

...

Additional arguments passed to or from other methods.

Examples

Run this code
# \donttest{
# Print the results from the wsize function
n <- c(10, 10, 10, 10)
means <- c(1, 0, 0, -1)
sd <- c(1, 1, 1, 1)
result <- wanova_pwr.test(n, means, sd, power = 0.90, alpha = 0.05)
print(result)
# }

Run the code above in your browser using DataLab